@@ -19,9 +19,12 @@ void __ChannelType()
         .value("OpacityChannel", Magick::OpacityChannel)
         .value("BlackChannel", Magick::BlackChannel)
         .value("MatteChannel", Magick::MatteChannel)
-#ifndef GM_1_1_x
+#ifdef PGMAGICK_LIB_GRAPHICSMAGICK_1_3_x
         .value("AllChannels", Magick::AllChannels)
         .value("GrayChannel", Magick::GrayChannel)
+#endif
+#ifdef PGMAGICK_LIB_IMAGEMAGICK
+        .value("AllChannels", Magick::AllChannels)
 #endif
     ;
 }
