@@ -10,7 +10,11 @@ namespace  {
 
 struct Magick_DrawableMiterLimit_Wrapper: Magick::DrawableMiterLimit
 {
+#ifdef PGMAGICK_LIB_IMAGEMAGICK
+    Magick_DrawableMiterLimit_Wrapper(PyObject* py_self_, size_t p0):
+#else
     Magick_DrawableMiterLimit_Wrapper(PyObject* py_self_, unsigned int p0):
+#endif
         Magick::DrawableMiterLimit(p0), py_self(py_self_) {}
 
 
@@ -23,8 +27,15 @@ struct Magick_DrawableMiterLimit_Wrapper: Magick::DrawableMiterLimit
 
 void __DrawableMiterLimit()
 {
+#ifdef PGMAGICK_LIB_IMAGEMAGICK
+    class_< Magick::DrawableMiterLimit, bases<Magick::DrawableBase>, boost::noncopyable, Magick_DrawableMiterLimit_Wrapper >("DrawableMiterLimit", init< size_t >())
+        .def("miterlimit", (void (Magick::DrawableMiterLimit::*)(size_t) )&Magick::DrawableMiterLimit::miterlimit)
+        .def("miterlimit", (size_t (Magick::DrawableMiterLimit::*)() const)&Magick::DrawableMiterLimit::miterlimit)
+    ;
+#else
     class_< Magick::DrawableMiterLimit, bases<Magick::DrawableBase>, boost::noncopyable, Magick_DrawableMiterLimit_Wrapper >("DrawableMiterLimit", init< unsigned int >())
         .def("miterlimit", (void (Magick::DrawableMiterLimit::*)(unsigned int) )&Magick::DrawableMiterLimit::miterlimit)
         .def("miterlimit", (unsigned int (Magick::DrawableMiterLimit::*)() const)&Magick::DrawableMiterLimit::miterlimit)
     ;
+#endif
 }
